"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _input = _interopRequireDefault(require("../input"));

var _component = _interopRequireDefault(require("./component"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* globals jest, describe, it, expect, beforeEach */
var changeValue = function changeValue(inputNode, value) {
  var inputDOMNode = inputNode.getDOMNode();
  inputDOMNode.value = value;
  inputNode.simulate('change');
};

describe('The <Input /> component', function () {
  (0, _component.default)(_input.default);
  describe('the initial render of the form control', function () {
    it('is `type="text"` by default', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput"
      }));
      expect(wrapper.find('input').prop('type')).toEqual('text');
    });
    it('has an initial value passed by prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput",
        value: "Initial value"
      }));
      expect(wrapper.find('input').prop('value')).toEqual('Initial value');
    });
    it('has a placeholder value passed by prop', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput",
        value: "",
        placeholder: "My placeholder"
      }));
      expect(wrapper.find('input').prop('placeholder')).toEqual('My placeholder');
    });
  });
  describe('has basic accessibility features', function () {
    var wrapper;
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput",
        id: "myId",
        label: "My Label",
        value: "Initial value"
      }));
    });
    it('has an `id` attribute on the form control', function () {
      expect(wrapper.find('input').prop('id')).toEqual('myId');
    });
    it('has a matching `htmlFor` attribute on the label', function () {
      var id = wrapper.find('input').prop('id');
      var htmlFor = wrapper.find('label').prop('htmlFor');
      expect(htmlFor).toEqual(id);
    }); // http://getbootstrap.com/css/#forms-help-text

    it('has an `aria-describedby` prop on the form control when help text is present', function () {});
    it('has an `aria-invalid="true"` prop on the form control when validation has failed', function () {});
    it('has an `aria-required="true"` prop on the form control when validation is required', function () {});
    /*
     * aria-hidden="true" on status glyphicons
     *
     * add sr-only feedback and aria-describedby in addidition to glyphicons.
     *
     * <div class="form-group has-success has-feedback">
     *   <label class="control-label" for="inputSuccess2">Input with success</label>
     *   <input
     *     type="text"
     *     class="form-control"
     *     id="inputSuccess2"
     *     aria-describedby="inputSuccess2Status"
     *   >
     *   <span class="glyphicon glyphicon-ok form-control-feedback" aria-hidden="true"></span>
     *   <span id="inputSuccess2Status" class="sr-only">(success)</span>
     * </div>
     */
  });
  describe('Input components do this', function () {
    var onBlurProp;
    var onChangeProp;
    var onSetValueProp;
    var wrapper;
    beforeEach(function () {
      jest.useFakeTimers();
      onBlurProp = jest.fn();
      onChangeProp = jest.fn();
      onSetValueProp = jest.fn();
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput",
        id: "myId",
        label: "My Label",
        value: "Initial value",
        onBlur: onBlurProp,
        onChange: onChangeProp,
        onSetValue: onSetValueProp
      }));
    }); // Test that this is a controlled component.

    it('updates the input value from props', function () {
      wrapper.setProps({
        value: 'Changed value'
      });
      expect(wrapper.find('input').prop('value')).toEqual('Changed value');
    });
    it('executes `props.onChange` when the <input /> value changes', function () {
      /*
       * The following doesn't work, we have to set the node's value directly:
       *
       * TestUtils.Simulate.change(node, {currentTarget: {value: 'Changed value'}});
       *
       * @see https://github.com/facebook/react/issues/3151#issuecomment-74943529
       */
      expect(onChangeProp).not.toBeCalled();
      var inputNode = wrapper.find('input');
      changeValue(inputNode, 'Changed value');
      expect(onChangeProp).toBeCalled();
      expect(wrapper.find('input').prop('value')).toEqual('Changed value');
    });
    it('debounces `props.onSetValue`', function () {
      expect(onChangeProp).not.toBeCalled();
      expect(onSetValueProp).not.toBeCalled();
      var inputNode = wrapper.find('input');
      changeValue(inputNode, 'a');
      changeValue(inputNode, 'b');
      changeValue(inputNode, 'c');
      expect(onChangeProp).toBeCalled();
      expect(onChangeProp).toHaveBeenCalledTimes(3);
      /*
       * The `onSetValueProp` function should be called after a period of
       * 500ms (it is debounced for change events).
       */

      expect(onSetValueProp).not.toBeCalled();
      jest.runAllTimers();
      expect(onSetValueProp).toBeCalled();
      expect(onSetValueProp).toHaveBeenCalledTimes(1);
    });
  });
  describe('includes an `<InputGroup />` component when', function () {
    it('is triggered by an `addonBefore` prop', function () {});
    it('is triggered by an `addonAfter` prop', function () {});
    it('is triggered by an `buttonBefore` prop', function () {});
    it('is triggered by an `buttonAfter` prop', function () {});
  });
  describe('for "hidden" type', function () {
    it('doesn’t render a label', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_input.default, {
        name: "myTestInput",
        type: "hidden",
        label: "My Label"
      }));
      expect(wrapper.find('label').length).toBe(0);
    });
  });
});